@@ -1,9 +1,11 @@
 import typing
 
-from di import AsyncExecutor, ConcurrentAsyncExecutor, Container, JoinedDependant
 from di.api.dependencies import DependantBase
-from di.api.executor import AsyncExecutorProtocol
+from di.api.executor import SupportsAsyncExecutor
 from di.api.solved import SolvedDependant
+from di.container import Container
+from di.dependant import JoinedDependant
+from di.executors import AsyncExecutor, ConcurrentAsyncExecutor
 from starlette.datastructures import URLPath
 from starlette.requests import HTTPConnection, Request
 from starlette.responses import JSONResponse, Response
@@ -33,7 +35,7 @@ class _OperationApp:
         self,
         dependant: SolvedDependant[typing.Any],
         container: Container,
-        executor: AsyncExecutorProtocol,
+        executor: SupportsAsyncExecutor,
         response_factory: typing.Callable[[typing.Any], Response],
         response_encoder: Encoder,
     ) -> None:
@@ -156,7 +158,7 @@ class Operation(BaseRoute):
         bodies = [dep for dep in flat if isinstance(dep, param_dependants.BodyBinder)]
         if len(bodies) > 1:
             raise ValueError("There can only be 1 top level body per operation")
-        executor: AsyncExecutorProtocol
+        executor: SupportsAsyncExecutor
         if self.execute_dependencies_concurrently:
             executor = ConcurrentAsyncExecutor()
         else:
